@@ -35,7 +35,7 @@
 ///        * Old: if (mu[n] != 0 && prime < lpf[n])
 ///        * New: if (prime < factor[n])
 ///
-/// Copyright (C) 2022 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2023 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -51,7 +51,7 @@
 #include <imath.hpp>
 #include <int128_t.hpp>
 #include <macros.hpp>
-#include <pod_vector.hpp>
+#include <Vector.hpp>
 
 #include <algorithm>
 #include <limits>
@@ -195,7 +195,7 @@ public:
   }
 
 private:
-  pod_vector<T> factor_;
+  Vector<T> factor_;
 };
 
 } // namespace
