@@ -13,7 +13,7 @@
 ///        method, Revista do DETUA, vol. 4, no. 6, March 2006,
 ///        pp. 759-768.
 ///
-/// Copyright (C) 2022 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2023 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -26,7 +26,7 @@
 #include <int128_t.hpp>
 #include <min.hpp>
 #include <imath.hpp>
-#include <pod_vector.hpp>
+#include <Vector.hpp>
 #include <print.hpp>
 #include <RelaxedAtomic.hpp>
 #include <StatusS2.hpp>
@@ -158,7 +158,7 @@ T S2_easy_OpenMP(T x,
                  bool is_print)
 {
   // Initialize libdivide vector from primes vector
-  pod_vector<libdivide::branchfree_divider<uint64_t>> lprimes;
+  Vector<libdivide::branchfree_divider<uint64_t>> lprimes;
   lprimes.resize(primes.size());
   for (std::size_t i = 1; i < lprimes.size(); i++)
     lprimes[i] = primes[i];
