@@ -1,7 +1,7 @@
 ///
 /// @file  generate.cpp
 ///
-/// Copyright (C) 2022 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2023 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -9,7 +9,7 @@
 
 #include <generate.hpp>
 #include <isqrt.hpp>
-#include <pod_vector.hpp>
+#include <Vector.hpp>
 
 #include <stdint.h>
 #include <limits>
@@ -21,11 +21,11 @@ namespace primecount {
 /// Generate a vector with the prime counts <= max
 /// using the sieve of Eratosthenes
 ///
-pod_vector<int32_t> generate_pi(int64_t max)
+Vector<int32_t> generate_pi(int64_t max)
 {
   int64_t sqrt = isqrt(max);
   int64_t size = max + 1;
-  pod_vector<bool> sieve(size);
+  Vector<bool> sieve(size);
   std::fill(sieve.begin(), sieve.end(), 1);
 
   for (int64_t i = 2; i <= sqrt; i++)
@@ -33,7 +33,7 @@ pod_vector<int32_t> generate_pi(int64_t max)
       for (int64_t j = i * i; j < size; j += i)
         sieve[j] = 0;
 
-  pod_vector<int32_t> pi(size);
+  Vector<int32_t> pi(size);
   std::fill(pi.begin(), pi.end(), 0);
   int32_t pix = 0;
 
@@ -50,11 +50,11 @@ pod_vector<int32_t> generate_pi(int64_t max)
 /// This implementation is based on code by Rick Sladkey:
 /// https://mathoverflow.net/q/99545
 ///
-pod_vector<int32_t> generate_moebius(int64_t max)
+Vector<int32_t> generate_moebius(int64_t max)
 {
   int64_t sqrt = isqrt(max);
   int64_t size = max + 1;
-  pod_vector<int32_t> mu(size);
+  Vector<int32_t> mu(size);
   std::fill(mu.begin(), mu.end(), 1);
 
   for (int64_t i = 2; i <= sqrt; i++)
@@ -87,11 +87,11 @@ pod_vector<int32_t> generate_moebius(int64_t max)
 /// of the integers <= max.
 /// @Examples: lfp(2) = 2, lpf(15) = 3
 ///
-pod_vector<int32_t> generate_lpf(int64_t max)
+Vector<int32_t> generate_lpf(int64_t max)
 {
   int64_t sqrt = isqrt(max);
   int64_t size = max + 1;
-  pod_vector<int32_t> lpf(size);
+  Vector<int32_t> lpf(size);
   std::fill(lpf.begin(), lpf.end(), 1);
 
   // By convention lfp(1) = +Infinity. Note that lpf(n) is
@@ -122,10 +122,10 @@ pod_vector<int32_t> generate_lpf(int64_t max)
 /// of the integers <= max.
 /// @Examples: mfp(2) = 2, mpf(15) = 5
 ///
-pod_vector<int32_t> generate_mpf(int64_t max)
+Vector<int32_t> generate_mpf(int64_t max)
 {
   int64_t size = max + 1;
-  pod_vector<int32_t> mpf(size);
+  Vector<int32_t> mpf(size);
   std::fill(mpf.begin(), mpf.end(), 1);
 
   for (int64_t i = 2; i <= max; i++)
