@@ -15,7 +15,7 @@
 ///        compressed lookup table of moebius function values,
 ///        least prime factors and max prime factors.
 ///
-/// Copyright (C) 2021 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2022 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -55,7 +55,7 @@ T D_thread(T x,
            const Primes& primes,
            const PiTable& pi,
            const FactorTableD& factor,
-           ThreadSettings& thread)
+           ThreadData& thread)
 {
   T sum = 0;
 
@@ -72,8 +72,8 @@ T D_thread(T x,
   if (min_b > max_b)
     return 0;
 
-  Sieve sieve(low, segment_size, max_b);
   auto phi = generate_phi(low, max_b, primes, pi);
+  Sieve sieve(low, segment_size, max_b);
   thread.init_finished();
 
   // Segmented sieve of Eratosthenes
@@ -192,14 +192,19 @@ T D_OpenMP(T x,
 {
   int64_t xz = x / z;
   int64_t x_star = get_x_star_gourdon(x, y);
+
+  // These load balancing settings work well on my
+  // dual-socket AMD EPYC 7642 server with 192 CPU cores.
   int64_t thread_threshold = 1 << 20;
-  threads = ideal_num_threads(threads, xz, thread_threshold);
+  int max_threads = (int) std::pow(xz, 1 / 3.7);
+  threads = std::min(threads, max_threads);
+  threads = ideal_num_threads(xz, threads, thread_threshold);
   LoadBalancerS2 loadBalancer(x, xz, d_approx, threads, is_print);
   PiTable pi(y, threads);
 
   #pragma omp parallel num_threads(threads)
   {
-    ThreadSettings thread;
+    ThreadData thread;
 
     while (loadBalancer.get_work(thread))
     {
@@ -231,14 +236,16 @@ int64_t D(int64_t x,
           int threads,
           bool is_print)
 {
+  double time;
+
   if (is_print)
   {
     print("");
     print("=== D(x, y) ===");
     print_gourdon_vars(x, y, z, k, threads);
+    time = get_time();
   }
 
-  double time = get_time();
   FactorTableD<uint16_t> factor(y, z, threads);
   auto primes = generate_primes<int32_t>(y);
   int64_t sum = D_OpenMP(x, y, z, k, d_approx, primes, factor, threads, is_print);
@@ -259,14 +266,16 @@ int128_t D(int128_t x,
            int threads,
            bool is_print)
 {
+  double time;
+
   if (is_print)
   {
     print("");
     print("=== D(x, y) ===");
     print_gourdon_vars(x, y, z, k, threads);
+    time = get_time();
   }
 
-  double time = get_time();
   int128_t sum;
 
   // uses less memory
