@@ -16,7 +16,7 @@
 ///        method, Revista do DETUA, vol. 4, no. 6, March 2006, p. 761.
 ///        http://sweet.ua.pt/tos/bib/5.4.pdf
 ///
-/// Copyright (C) 2022 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2023 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -32,7 +32,7 @@
 #include <PhiTiny.hpp>
 #include <PiTable.hpp>
 #include <print.hpp>
-#include <pod_vector.hpp>
+#include <Vector.hpp>
 #include <popcnt.hpp>
 
 #include <stdint.h>
@@ -49,7 +49,7 @@ class PhiCache : public BitSieve240
 public:
   PhiCache(uint64_t x,
            uint64_t a,
-           const pod_vector<int32_t>& primes,
+           const Vector<int32_t>& primes,
            const PiTable& pi) :
     primes_(primes),
     pi_(pi)
@@ -292,8 +292,8 @@ private:
   /// by any of the the first a primes. sieve[a][i].count
   /// contains the count of numbers < i * 240 that are not
   /// divisible by any of the first a primes.
-  pod_vector<pod_vector<sieve_t>> sieve_;
-  const pod_vector<int32_t>& primes_;
+  Vector<Vector<sieve_t>> sieve_;
+  const Vector<int32_t>& primes_;
   const PiTable& pi_;
 };
 
